<?php
// wcf imports
require_once(WCF_DIR.'lib/data/rule/RuleItemEditor.class.php');
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');
require_once(WCF_DIR.'lib/data/rule/Ruleset.class.php');

/**
 * Shows the rule item add form.
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	acp.form
 * @category 	Community Framework (commercial)
 */
class RuleItemAddForm extends ACPForm {
	/**
	 * Template name
	 *
	 * @var	string
	 */
	public $templateName = 'ruleItemAdd';
	
	/**
	 * Active menu item
	 *
	 * @var	string
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.ruleItem.add';
	
	/**
	 * Permission
	 *
	 * @var	string
	 */
	public $neededPermissions = 'admin.rule.canAddItem';

	/**
	 * Rule item editor object
	 *
	 * @var	RuleItemEditor
	 */
	public $ruleItem = null;

	/**
	 * Topic
	 *
	 * @var	string
	 */
	public $topic = '';
	
	/**
	 * Parent Item
	 *
	 * @var	string
	 */
	public $parentItem = '';
	
	/**
	 * Text
	 *
	 * @var	string
	 */
	public $text = '';
	
	/**
	 * Position
	 *
	 * @var	integer
	 */
	public $showOrder = 0;
	
	/**
	 * Language id
	 *
	 * @var	integer
	 */
	public $languageID = 0;
	
	/**
	 * Rule item ID
	 *
	 * @var	integer
	 */
	public $ruleItemID = 0;

	/**
	 * rule item list
	 *
	 * @var array<array>
	 */
	public $ruleItemList = array();

	/**
	 * structured rule item list
	 *
	 * @var array<array>
	 */
	public $ruleItems = array();
	
	public $ruleset = null;

	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['rulesetID'])) {
			$this->ruleset = new Ruleset(intval($_REQUEST['rulesetID']));
		}
		if ($this->ruleset === null || !$this->ruleset->rulesetID) {
				$this->ruleset = Ruleset::getActiveRuleset();
		}
	}
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();

		if (isset($_POST['parentItem'])) $this->parentItem = $_POST['parentItem'];
		if (isset($_POST['showOrder'])) $this->showOrder = intval($_POST['showOrder']);
		if (isset($_POST['topic'])) $this->topic = StringUtil::trim($_POST['topic']);
		if (isset($_POST['text'])) $this->text = StringUtil::trim($_POST['text']);
		if (isset($_POST['languageID'])) $this->languageID = intval($_POST['languageID']);
	}

	/**
	 * @see Form::validate()
	 */
	public function validate() {
		parent::validate();

		//  validate topic
		$this->validateTopic();
	}

	/**
	 * Validates the given topic.
	 */
	public function validateTopic() {
		if (empty($this->topic)) {
			throw new UserInputException('topic');
		}
	}

	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();

		$this->readRuleItems();
		$this->makeRuleItemList();
	}

	/**
	 * Gets a list of all rule items.
	 */
	protected function readRuleItems() {
		$sql = "SELECT		*
			FROM		wcf".WCF_N."_rule_item
			WHERE		rulesetID = ".$this->ruleset->rulesetID."
					".(($this->ruleItemID != 0) ? ("AND ruleItemID <> ".$this->ruleItemID) : (""))."
			ORDER BY	parentRuleItem, showOrder";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$this->ruleItems[$row['parentRuleItem']][] = new RuleItem(null, $row);
		}
	}

	/**
	 * Renders one level of the rule item structure.
	 *
	 * @param	integer		$parentRuleItem
	 * @param	integer		$depth
	 */
	protected function makeRuleItemList($parentRuleItem = '', $depth = 1) {
		if (!isset($this->ruleItems[$parentRuleItem])) return;

		foreach ($this->ruleItems[$parentRuleItem] as $ruleItem) {
			// we must encode html here because the htmloptions plugin doesn't do it
			$title = WCF::getLanguage()->get('wcf.rules.item.'.StringUtil::encodeHTML($ruleItem->ruleItem));
			if ($depth > 0) $title = str_repeat('&nbsp;&nbsp;&nbsp;&nbsp;', $depth). ' ' . $title;
			$this->ruleItemList[$ruleItem->ruleItem] = $title;

			// make next level of the list
			$this->makeRuleItemList($ruleItem->ruleItem, $depth + 1);
		}
	}

	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();

		// save
		$this->RuleItem = RuleItemEditor::create($this->ruleset->rulesetID, $this->topic, $this->text, $this->parentItem, $this->showOrder, WCF::getLanguage()->getLanguageID());
		$this->saved();

		// reset values
		$this->topic = $this->text = $this->parentItem = '';
		$this->languageID = $this->showOrder = 0;

		// show success message
		WCF::getTPL()->assign('success', true);
	}

	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();

		WCF::getTPL()->assign(array(
			'items' => $this->ruleItemList,
			'topic' => $this->topic,
			'parentItem' => $this->parentItem,
			'text' => $this->text,
			'showOrder' => $this->showOrder,
			'ruleItem' => $this->ruleItem,
			'languageID' => $this->languageID,
			'ruleset' => $this->ruleset,
			'action' => 'add'
		));
	}
}
?>