<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/RuleItemAddForm.class.php');

/**
 * Shows ruleset edit form.
 * 
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	acp.form
 * @category 	Community Framework (commercial)
 */
class RuleItemEditForm extends RuleItemAddForm {
	/**
	 * Active menu item
	 *
	 * @var	string
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.ruleItem.view';

	/**
	 * Permission
	 *
	 * @var	string
	 */
	public $neededPermissions = 'admin.rule.canEditItem';

	/**
	 * Languages
	 *
	 * @var array<string>
	 */
	public $languages = array();

	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();

		// language
		if (isset($_REQUEST['languageID'])) $this->languageID = intval($_REQUEST['languageID']);
		else $this->languageID = WCF::getLanguage()->getLanguageID();

		// rule item
		if (isset($_REQUEST['ruleItemID'])) $this->ruleItemID = intval($_REQUEST['ruleItemID']);
		$this->ruleItem = new RuleItemEditor($this->ruleItemID);
		if (!$this->ruleItem->ruleItemID) {
			throw new IllegalLinkException();
		}
	}

	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();

		// get all available languages
		$this->languages = WCF::getLanguage()->getLanguageCodes();
		
		// rekursion fail.
		if ($this->parentItem == $this->ruleItem->ruleItem) {
			$this->parentItem = $this->ruleItem->parentRuleItem;
		}

		// default values
		if (!count($_POST)) {
			$this->showOrder = $this->ruleItem->showOrder;
			$this->parentItem = $this->ruleItem->parentRuleItem;

			if (WCF::getLanguage()->getLanguageID() != $this->languageID) {
				$language = new Language($this->languageID);
			}
			else {
				$language = WCF::getLanguage();
			}

			$this->topic = $language->get('wcf.rules.item.'.$this->ruleItem->ruleItem);
			if ($this->topic == 'wcf.rules.item.'.$this->ruleItem->ruleItem) $this->topic = "";
			$this->text = $language->get('wcf.rules.item.'.$this->ruleItem->ruleItem.'.description');
			if ($this->text == 'wcf.rules.item.'.$this->ruleItem->ruleItem.'.description') $this->text = "";
		}
	}

	/**
	 * @see Form::save()
	 */
	public function save() {
		AbstractForm::save();

		// update item
		$this->ruleItem->update($this->topic, $this->text, $this->parentItem, $this->showOrder, $this->languageID);
		$this->saved();

		// show success message
		WCF::getTPL()->assign('success', true);
	}

	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();

		WCF::getTPL()->assign(array(
			'action' => 'edit',
			'ruleItemID' => $this->ruleItemID,
			'languages' => $this->languages
		));
	}
}
?>