<?php
// wcf imports
require_once(WCF_DIR.'lib/acp/form/ACPForm.class.php');
require_once(WCF_DIR.'lib/data/rule/RulesetEditor.class.php');

/**
 * Shows the ruleset form.
 * 
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	acp.form
 * @category 	Community Framework (commercial)
 */
class RulesetForm extends ACPForm {
	/**
	 * Template name
	 *
	 * @var	string
	 */
	public $templateName = 'rulesetForm';
	
	/**
	 * Active menu item
	 *
	 * @var	string
	 */
	public $activeMenuItem = 'wcf.acp.menu.link.ruleItem.view';
	
	/**
	 * Permission
	 *
	 * @var	array<string>
	 */
	public $neededPermissions = array('admin.rule.ruleset.canAdd', 'admin.rule.ruleset.canEdit');
	
	/**
	 * Method
	 * 
	 * Contains edit for edit a ruleset, 
	 * add for create a ruleset and active for make a ruleset activ.
	 *
	 * @var	string
	 */
	public $method = '';
	
	/**
	 * Applications
	 *
	 * @var	array
	 */
	public $applicationList = array();
	
	/**
	 * Rulesets
	 *
	 * @var	array
	 */
	public $rulesetEditList = array();
	
	/**
	 * Rulset html options
	 *
	 * @var	array
	 */
	public $rulesetOptionList = array();
	
	/**
	 * Ruleset name
	 *
	 * @var	string
	 */
	public $name = '';
	
	/**
	 * Rulesets names
	 *
	 * @var	array<string>
	 */
	public $editRuleset = array();
	
	/**
	 * Ruleset make active
	 *
	 * @var array
	 */
	public $makeActive = array();
	
	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		if (isset($_REQUEST['method'])) $this->method = StringUtil::trim(StringUtil::toLowerCase($_REQUEST['method']));
	}
	
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		// select the post parameters for every method.
		switch ($this->method) {
			case 'add':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canAdd')) {
					if (isset($_POST['name'])) $this->name = StringUtil::trim($_POST['name']);
				}
				break;
				
			case 'edit':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canEdit')) {
					if (isset($_POST['editRuleset'])) $this->editRuleset = ArrayUtil::trim($_POST['editRuleset']);
				}
				break;
				
			case 'active':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canEdit')) {
					if (isset($_POST['makeActive'])) $this->makeActive = ArrayUtil::toIntegerArray($_POST['makeActive']);
				}
				break;
		}
	}
	
	/**
	 * @see Form::validate()
	 */
	public function validate() {
		parent::validate();
		
		switch ($this->method) {
			
			// check the name for a new ruleset
			case 'add':
				if ($this->name == '') throw new UserInputException('name');
				if (RulesetEditor::existName($this->name)) throw new UserInputException('name', 'notUnique');
				break;

			// check the names of the changed ruleset, if the name in use, we throw a exception
			case 'edit':
				if (count($this->editRuleset)) {
					$nameUsed = array();
					$errorFields = array();
					foreach ($this->editRuleset AS $rulesetID => $newName) {
						$rulesetID = intval($rulesetID);
						if($newName == '') {
							$errorFields[$rulesetID] = 'empty';
						}
						else if (in_array($newName, $nameUsed) || RulesetEditor::existName($newName, $rulesetID)) {
							$errorFields[$rulesetID] = 'notUnique';
						}
						else $nameUsed[] = $newName;
					}
					if (count($errorFields)) {
						WCF::getTPL()->assign('errorFields', $errorFields);
						throw new UserInputException('editRuleset');
					}
				}
				break;	
		}
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		
		switch ($this->method) {
			// add a new ruleset
			case 'add':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canAdd')) {
					// create a new ruleset
					RulesetEditor::create($this->name);
					$this->name = '';
					WCF::getTPL()->assign(array('addSuccess' => true));
				}
				break;
				
			// edit existing rulesets
			case 'edit':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canEdit')) {
					// update ruleset name
					if (count($this->editRuleset)) {
						foreach ($this->editRuleset AS $rulesetID => $newName) {
							$rulesetID = intval($rulesetID);
							$ruleset = new RulesetEditor($rulesetID);
							
							// if the ruleset not exists, we go to the next.
							if (!$ruleset->rulesetID) continue;
							
							$ruleset->update($newName);
							$edit = true;
						}
						unset($ruleset);
					}

					WCF::getTPL()->assign(array('editSuccess' => $edit));
					$this->editRuleset = array();
				}
				break;

			// set active rulesets for applications/standalone packages
			case 'active':
				if (WCF::getUser()->getPermission('admin.rule.ruleset.canEdit')) {
					if (count($this->makeActive)) {
						//creates a default ruleset object and a empty array for save querys
						$defaultRuleset = new RulesetEditor(1);
						$rulesetList = array();
						
						foreach ($this->makeActive AS $packageID => $rulesetID) {
							$packageID = intval($packageID);
							// if the ruleset id 1, we only need the default ruleset.
							if ($rulesetID == 1) $defaultRuleset->makeActive($packageID);
							else {
								
								// if we have the ruleset with a given id, we use this from the array, else we send the sql query and save it to the array
								if (isset($rulesetList[$rulesetID])) {
									$rulesetList[$rulesetID]->makeActive($packageID);
								}
								else {
									$ruleset = new RulesetEditor($rulesetID);
									if (!$ruleset->rulesetID) {
										$defaultRuleset->makeActive($packageID);
									}
									else {
										$ruleset->makeActive($packageID);
										$rulesetList[$ruleset->rulesetID] = $ruleset;
										unset($ruleset);
									}
								}
							}
						}
						unset($defaultRuleset, $rulesetList);
						$this->makeActive = array();
						WCF::getTPL()->assign(array('activeSuccess' => true));
					}
				}
				break;
		}
		
		$this->saved();
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		$this->rulesetOptionList = RulesetEditor::getOptionList();
		$this->rulesetEditList = RulesetEditor::getRulesetList();
		$this->applicationList = RulesetEditor::getApplications();
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign(array(
			//standard values
			'rulesetOptionList' => $this->rulesetOptionList,
			'rulesetEditList' => $this->rulesetEditList,
			'applicationList' => $this->applicationList,
		
			//values from parameters
			'name' => $this->name,
			'editRuleset' => $this->editRuleset,
			'method' => $this->method
			));
	}
}
?>