<?php
// wcf imports
require_once(WCF_DIR.'lib/page/AbstractPage.class.php');
require_once(WCF_DIR.'lib/data/rule/RuleItem.class.php');
require_once(WCF_DIR.'lib/data/rule/RulesetEditor.class.php');

/**
 * Shows a list of all rule items.
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	acp.page
 * @category 	Community Framework (commercial)
 */
class RuleItemListPage extends AbstractPage {
	/**
	 * Template name
	 *
	 * @var	string
	 */
	public $templateName = 'ruleItemList';
	
	/**
	 * Delte rule item id
	 *
	 * @var	integer
	 */
	public $deletedRuleItemID = 0;
	
	/**
	 * delete agreements status
	 *
	 * @var	boolean
	 */
	public $deletedAgreements = false;
	
	/**
	 * If the list was sorted successfully
	 *
	 * @var boolean
	 */
	public $successfullSorting = false;

	/**
	 * rule item list
	 *
	 * @var array<array>
	 */
	public $ruleItemList = array();

	/**
	 * structured rule item list
	 *
	 * @var array<array>
	 */
	public $ruleItems = array();
	
	/**
	 * Current ruleset
	 *
	 * @var Ruleset
	 */
	public $ruleset = null;
	
	/**
	 * Ruleset html option list
	 *
	 * @var array
	 */
	public $rulesetOptionList = null;
	
	/**
	 * If more than one application exits
	 *
	 * @var boolean
	 */
	public $applications = false;

	/**
	 * @see Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();

		if (isset($_REQUEST['successfullSorting'])) $this->successfullSorting = true;
		if (isset($_REQUEST['deletedRuleItemID'])) $this->deletedRuleItemID = intval($_REQUEST['deletedRuleItemID']);
		if (isset($_REQUEST['deletedAgreements'])) $this->deletedAgreements = true;
		if (isset($_REQUEST['rulesetID'])) {
			$this->ruleset = new Ruleset(intval($_REQUEST['rulesetID']));
		}
		if ($this->ruleset === null || !$this->ruleset->rulesetID) {
				$this->ruleset = Ruleset::getActiveRuleset();
		}

	}

	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();

		$this->readRuleItems();
		$this->makeRuleItemList();
		
		$this->rulesetOptionList = RulesetEditor::getOptionList();
		$applications = RulesetEditor::getApplications();
		$this->applications = count($applications);

	}

	/**
	 * Gets a list of all rule items.
	 */
	protected function readRuleItems() {
		$sql = "SELECT		rule_item.*,
					IFNULL((SELECT ruleItemID FROM wcf".WCF_N."_rule_item WHERE ruleItem = rule_item.parentRuleItem LIMIT 1), 0) AS parentRuleItemID
			FROM		wcf".WCF_N."_rule_item rule_item
			WHERE		rulesetID = ".$this->ruleset->rulesetID."
			ORDER BY	parentRuleItemID, showOrder";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$this->ruleItems[$row['parentRuleItemID']][] = new RuleItem(null, $row);
		}
	}

	/**
	 * Renders one level of the help item structure.
	 *
	 * @param	integer		$parentHelpItemID
	 * @param	integer		$depth
	 * @param	integer		$openParents
	 */
	protected function makeRuleItemList($parentRuleItemID = 0, $depth = 1, $openParents = 0) {
		if (!isset($this->ruleItems[$parentRuleItemID])) return;

		$i = 0; $children = count($this->ruleItems[$parentRuleItemID]);
		foreach ($this->ruleItems[$parentRuleItemID] as $ruleItem) {
			$childrenOpenParents = $openParents + 1;
			$hasChildren = isset($this->ruleItems[$ruleItem->ruleItemID]);
			$last = $i == count($this->ruleItems[$parentRuleItemID]) - 1;
			if ($hasChildren && !$last) $childrenOpenParents = 1;
			$this->ruleItemList[] = array('depth' => $depth, 'hasChildren' => $hasChildren, 'openParents' => ((!$hasChildren && $last) ? ($openParents) : (0)), 'ruleItem' => $ruleItem, 'position' => $i + 1, 'maxPosition' => $children);

			// make next level of the list
			$this->makeRuleItemList($ruleItem->ruleItemID, $depth + 1, $childrenOpenParents);
			$i++;
		}
	}

	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();

		WCF::getTPL()->assign(array(
			'ruleItems' => $this->ruleItemList,
			'deletedRuleItemID' => $this->deletedRuleItemID,
			'successfullSorting' => $this->successfullSorting,
			'deletedAgreements' => $this->deletedAgreements,
			'ruleset' => $this->ruleset,
			'rulesetOptionList' => $this->rulesetOptionList,
			'applications' => $this->applications,
		));
	}

	/**
	 * @see Page::show()
	 */
	public function show() {
		// check user permission
		WCF::getUser()->checkPermission(array('admin.rule.canEditItem', 'admin.rule.canDeleteItem'));
		
		// enable menu item
		WCFACP::getMenu()->setActiveMenuItem('wcf.acp.menu.link.ruleItem.view');

		parent::show();
	}
}
?>