<?php
require_once(WCF_DIR.'lib/data/rule/RuleItem.class.php');
require_once(WCF_DIR.'lib/system/language/LanguageEditor.class.php');

/**
 * Provides functions to edit rule items.
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	data.rule
 * @category 	Community Framework (commercial)
 */
class RuleItemEditor extends RuleItem {
	/**
	 * Creates a new rule item.
	 *
	 * @param 	string		$name
	 * @param 	string		$text
	 * @param 	string		$parentItem
	 * @param 	string		$refererPattern
	 * @param 	integer		$showOrder
	 * @param 	boolean		$isDisabled
	 * @param 	integer		$languageID
	 * @param	integer		$packageID
	 *
	 * @return	HelpItemEditor
	 */
	public static function create($rulesetID, $name, $text = '', $parentItem = '', $showOrder = 0, $languageID = 0) {
		// get show order
		if ($showOrder == 0) {
			// get next number in row
			$sql = "SELECT	MAX(showOrder) AS showOrder
				FROM	wcf".WCF_N."_rule_item
				WHERE	parentRuleItem = '".escapeString($parentItem)."'
					AND rulesetID = ".$rulesetID;
			$row = WCF::getDB()->getFirstRow($sql);
			if (!empty($row)) $showOrder = intval($row['showOrder']) + 1;
			else $showOrder = 1;
		}
		else {
			$sql = "UPDATE	wcf".WCF_N."_rule_item
				SET 	showOrder = showOrder + 1
				WHERE 	showOrder >= ".$showOrder."
					AND parentRuleItem = '".escapeString($parentItem)."'
					AND rulesetID = ".$rulesetID;
			WCF::getDB()->sendQuery($sql);
		}

		// get menu item name
		$ruleItem = '';
		if ($languageID == 0) $ruleItem = $name;

		// save
		$sql = "INSERT INTO	wcf".WCF_N."_rule_item
					(ruleItem, parentRuleItem, rulesetID, showOrder)
			VALUES		('".escapeString($ruleItem)."', '".escapeString($parentItem)."', ".$rulesetID.", ".$showOrder.")";
		WCF::getDB()->sendQuery($sql);

		// get item id
		$ruleItemID = WCF::getDB()->getInsertID("wcf".WCF_N."_rule_item", 'ruleItemID');

		if ($languageID != 0) {
			// set name
			$ruleItem = "item".$ruleItemID;
			$sql = "UPDATE	wcf".WCF_N."_rule_item
				SET	ruleItem = '".escapeString($ruleItem)."'
				WHERE 	ruleItemID = ".$ruleItemID;
			WCF::getDB()->sendQuery($sql);

			// save language variables
			$language = new LanguageEditor($languageID);
			$language->updateItems(array('wcf.rules.item.'.$ruleItem => $name, 'wcf.rules.item.'.$ruleItem.'.description' => $text), 0, WCF::getPackageID('com.woltlab.wcf.termsOfUse'));
			LanguageEditor::deleteLanguageFiles($languageID, 'wcf.rules');
		}
		
		return new RuleItemEditor($ruleItemID);
	}

	/**
	 * Updates this rule item.
	 *
	 * @param 	string		$name
	 * @param 	string		$text
	 * @param 	string		$parentItem
	 * @param 	string		$refererPattern
	 * @param 	integer		$showOrder
	 * @param 	boolean		$isDisabled
	 * @param	integer		$languageID
	 * @param	integer		$packageID
	 */
	public function update($name, $text = '', $parentItem = '', $showOrder = 0, $languageID = 0) {
		if ($parentItem == $this->ruleItem) {
			$parentItem = $this->parentRuleItem;
		}
		
		// update show order
		if ($parentItem == $this->parentRuleItem) {
			if ($this->showOrder != $showOrder) {
				if ($showOrder < $this->showOrder) {
					$sql = "UPDATE	wcf".WCF_N."_rule_item
						SET 	showOrder = showOrder + 1
						WHERE 	showOrder >= ".$showOrder."
							AND showOrder < ".$this->showOrder."
							AND parentRuleItem = '".escapeString($parentItem)."'
							AND rulesetID = ".$this->rulesetID;
					WCF::getDB()->sendQuery($sql);
				}
				else if ($showOrder > $this->showOrder) {
					$sql = "UPDATE	wcf".WCF_N."_rule_item
						SET	showOrder = showOrder - 1
						WHERE	showOrder <= ".$showOrder."
							AND showOrder > ".$this->showOrder."
							AND parentRuleItem = '".escapeString($parentItem)."'
							AND rulesetID = ".$this->rulesetID;
					WCF::getDB()->sendQuery($sql);
				}
			}
		}
		else {
			$sql = "UPDATE	wcf".WCF_N."_rule_item
				SET 	showOrder = showOrder - 1
				WHERE 	showOrder >= ".$this->showOrder."
					AND parentRuleItem = '".escapeString($this->parentRuleItem)."'
					AND rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);

			$sql = "UPDATE 	wcf".WCF_N."_rule_item
				SET 	showOrder = showOrder + 1
				WHERE 	showOrder >= ".$showOrder."
					AND parentRuleItem = '".escapeString($parentItem)."'
					AND rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);
		}

		// Update
		$sql = "UPDATE	wcf".WCF_N."_rule_item
			SET	".($languageID == 0 ? "ruleItem = '".escapeString($name)."'," : '')."
				parentRuleItem = '".escapeString($parentItem)."',
				showOrder = ".$showOrder."
			WHERE 	ruleItemID = ".$this->ruleItemID;
		WCF::getDB()->sendQuery($sql);

		if ($languageID != 0) {
			// save language variables
			$language = new LanguageEditor($languageID);
			$language->updateItems(array('wcf.rules.item.'.$this->ruleItem => $name, 'wcf.rules.item.'.$this->ruleItem.'.description' => $text), 0, PACKAGE_ID, array('wcf.rules.item.'.$this->ruleItem => 1, 'wcf.rules.item.'.$this->ruleItem.'.description' => 1));
			LanguageEditor::deleteLanguageFiles($languageID, 'wcf.rules');		
		}
	}

	/**
	 * Deletes this rule item.
	 */
	public function delete() {
		// update show order
		$sql = "UPDATE	wcf".WCF_N."_rule_item
			SET	showOrder = showOrder - 1
			WHERE	showOrder >= ".$this->showOrder."
				AND parentRuleItem = '".escapeString($this->parentRuleItem)."'
				AND rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);

		// update children
		$sql = "UPDATE	wcf".WCF_N."_rule_item
			SET	parentRuleItem = '".escapeString($this->parentRuleItem)."'
			WHERE	parentRuleItem = '".escapeString($this->ruleItem)."'
				AND rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);

		// delete item
		$sql = "DELETE FROM	wcf".WCF_N."_rule_item
			WHERE		ruleItemID = ".$this->ruleItemID."
				AND rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);

		// delete language variables
		LanguageEditor::deleteVariable('wcf.rules.item.'.$this->ruleItem);
		LanguageEditor::deleteVariable('wcf.rules.item.'.$this->ruleItem.'.description');
	}


	/**
	 * Updates the positions of a rule item directly.
	 *
	 * @param	integer		$helpItemID
	 * @param	string		$parentItem
	 * @param	integer		$position
	 */
	public static function updateShowOrder($ruleItemID, $parentItem, $position) {
		$sql = "UPDATE	wcf".WCF_N."_rule_item
			SET	parentRuleItem = '".escapeString($parentItem)."',
				showOrder = ".$position."
			WHERE 	ruleItemID = ".$ruleItemID;
		WCF::getDB()->sendQuery($sql);
	}
}
?>