<?php
// wcf imports
require_once(WCF_DIR.'lib/data/rule/RuleItem.class.php');

/**
 * List with all rules of a ruleset.
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	data.rule
 * @category 	Community Framework (commercial)
 */
class RuleList {
	/**
	 * Ruleset ID
	 *
	 * @var	integer
	 */
	protected $rulesetID = 0;
	
	/**
	 * Array with unsorted rules
	 *
	 * @var	array<mixed>
	 */
	protected $unsortedRules = array();
	
	/**
	 * Array with sorted rules
	 *
	 * @var	array<mixed>
	 */
	protected $sortedRules = array();
	
	/**
	 * Start the rulelist object.
	 *
	 * @param	integer		$rulesetID
	 */
	public function __construct($rulesetID) {
		$this->rulesetID = $rulesetID;
		
		$this->readRules();
		$this->sortRules();
	}
	
	/**
	 * Returns the sorted rules.
	 *
	 * @return	array<mixed>
	 */
	public function getRules() {
		return $this->sortedRules;
	}
	
	/**
	 * Read all rule items of a ruleset from the database.
	 *
	 */
	protected function readRules() {
		$sql = "SELECT		rule_item.*,
					IFNULL((SELECT ruleItemID FROM wcf".WCF_N."_rule_item WHERE ruleItem = rule_item.parentRuleItem LIMIT 1), 0) AS parentRuleItemID
			FROM		wcf".WCF_N."_rule_item rule_item
			WHERE		rulesetID = ".$this->rulesetID."
			ORDER BY	parentRuleItemID, showOrder";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$this->unsortedRules[$row['parentRuleItemID']][] = new RuleItem(null, $row);
		}
	}


	/**
	 * Renders one level of the rule item structure.
	 *
	 * @param	integer		$parentHelpItemID
	 * @param	integer		$depth
	 * @param	integer		$openParents
	 */
	protected function sortRules($parentRuleItemID = 0, $depth = 1, $openParents = 0) {
		if (!isset($this->unsortedRules[$parentRuleItemID])) return;

		$i = 0; 
		foreach ($this->unsortedRules[$parentRuleItemID] as $ruleItem) {
			$childrenOpenParents = $openParents + 1;
			$hasChildren = isset($this->unsortedRules[$ruleItem->ruleItemID]);
			$last = $i == count($this->unsortedRules[$parentRuleItemID]) - 1;
			if ($hasChildren && !$last) $childrenOpenParents = 1;
			$this->sortedRules[] = array('depth' => $depth, 'hasChildren' => $hasChildren, 'openParents' => ((!$hasChildren && $last) ? ($openParents) : (0)), 'ruleItem' => $ruleItem, 'position' => $i + 1);

			// make next level of the list
			$this->sortRules($ruleItem->ruleItemID, $depth + 1, $childrenOpenParents);
			$i++;
		}
	}
	
}
?>