<?php
// wcf imports
require_once(WCF_DIR.'lib/data/DatabaseObject.class.php');
require_once(WCF_DIR.'lib/data/rule/RuleList.class.php');

/**
 * This class represents a ruleset
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	data.rule
 * @category 	Community Framework (commercial)
 */
class Ruleset extends DatabaseObject {
	/**
	 * Ruleset of the active application.
	 *
	 * @var	Ruleset
	 */
	protected static $activeRuleset = null;
	
	/**
	 * Rule list.
	 *
	 * @var	RuleList
	 */
	protected $ruleList = null;
	
	/**
	 * Creates a ruleset object.
	 *
	 * @param	integer		$rulesetID
	 * @param	array<mixed>	$row
	 */
	public function __construct($rulesetID, $row = null) {
		if ($rulesetID !== null) {
			$sql = "SELECT	*
				FROM	wcf".WCF_N."_ruleset
				WHERE	rulesetID = ".$rulesetID;
			$row = WCF::getDB()->getFirstRow($sql);
		}
		
		parent::handleData($row);
	}
	
	/**
	 * Returns the RuleList object.
	 *
	 * @return	RuleList
	 */
	public function getRuleList() {
		if ($this->ruleList === null) {
			$this->ruleList = new RuleList($this->rulesetID);
		}
		
		return $this->ruleList;
	}
	
	/**
	 * Set the agreement flag for a user.
	 *
	 * @param	integer		$userID
	 */
	public function makeUserAgree($userID = null) {
		// select the current user id of the session
		if ($userID === null) {
			$userID = WCF::getUser()->userID;
		}
		
		// delete the current entry if this entry exists.
		$sql = "DELETE FROM	wcf".WCF_N."_ruleset_to_user
			WHERE		userID = ".$userID."
				AND	rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);
		
		// insert the agree entry
		$sql = "INSERT INTO	wcf".WCF_N."_ruleset_to_user
					(userID, rulesetID)
			VALUES		(".$userID.", ".$this->rulesetID.")";
		WCF::getDB()->sendQuery($sql);
	}
	
	/**
	 * Returns the RulesetEditor object
	 *
	 * @return	RulesetEditor
	 */
	public function getEditor() {
		return new RulesetEditor(null, $this->data);
	}
	
	/**
	 * Make a ruleset to the active ruleset for a package.
	 *
	 * @param	integer		$packageID
	 */
	public function makeActive($packageID = PACKAGE_ID) {
		// delete all ruleset_to_package entry from the given package
		$sql = "DELETE FROM	wcf".WCF_N."_ruleset_to_package
			WHERE		packageID = ".$packageID;
		WCF::getDB()->sendQuery($sql);
	
		// set a new ruleset as the active ruleset from the given package
		$sql = "INSERT INTO	wcf".WCF_N."_ruleset_to_package
					(rulesetID, packageID)
			VALUES		(".$this->rulesetID.", ".$packageID.")";
		WCF::getDB()->sendQuery($sql);
	}

	/**
	 * Check the given user ID for the agreementflag for a ruleset.
	 *
	 * @param	integer		$userID
	 * @param	integer		$packageID
	 * @return	boolean
	 */
	public static function isUserAgree($userID = null, $packageID = PACKAGE_ID) {
		if ($userID === null) {
			$userID = WCF::getUser()->userID;
		}
		
		$sql = "SELECT	COUNT(*) AS count
			FROM	wcf".WCF_N."_ruleset_to_user
			WHERE	userID = ".$userID."
				AND rulesetID = ".self::getActiveRulesetID($packageID);
		$row = WCF::getDB()->getFirstRow($sql);
		return ($row['count'] > 0) ? true : false;	
	}

	/**
	 * Returns the active ruleset of a application.
	 *
	 * @param	integer		$packageID
	 * @return	Ruleset
	 */
	public static function getActiveRuleset($packageID = PACKAGE_ID) {
		if (self::$activeRuleset === null) {
			$sql = "SELECT	rulesetID
				FROM	wcf".WCF_N."_ruleset_to_package
				WHERE	packageID = ".PACKAGE_ID;
			$row = WCF::getDB()->getFirstRow($sql);
			if (!isset($row['rulesetID'])) $ruleset = new Ruleset(1);
			else $ruleset = new Ruleset($row['rulesetID']);
			
			// check the ruleset id, if we do not have a ruleset id, we give the standardruleset back.
			if (!$ruleset->rulesetID) {
				$ruleset = new Ruleset(1);
				$ruleset->makeActive($packageID);
			}
			self::$activeRuleset = $ruleset;
		}
		
		return self::$activeRuleset;
	}

	/**
	 * Returns the ID of the active ruleset of a package.
	 *
	 * @param	integer		$packageID
	 * @return	integer
	 */
	public static function getActiveRulesetID($packageID = PACKAGE_ID) {
		if (self::$activeRuleset === null) self::getActiveruleset($packageID);
		return self::$activeRuleset->rulesetID;
	}
}
?>