<?php
// wcf imports
require_once(WCF_DIR.'lib/data/rule/Ruleset.class.php');

/**
 * Extends the ruleset class with special methods for edit/create a ruleset
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	data.rule
 * @category 	Community Framework (commercial)
 */
class RulesetEditor extends Ruleset {
	/**
	 * Delete the agreements from the user completely.
	 */
	public function deleteUserAgreements() {
		$sql = "DELETE FROM	wcf".WCF_N."_ruleset_to_user
			WHERE		rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);
	}
	
	/**
	 * Updates a ruleset
	 *
	 * @param	string		$name
	 */
	public function update($name) {
		// update name
		$sql = "UPDATE	wcf".WCF_N."_ruleset
			SET	name = '".escapeString($name)."'
			WHERE	rulesetID = ".$this->rulesetID;
		WCF::getDB()->sendQuery($sql);
	}
	
	/**
	 * Delete a ruleset.
	 *
	 * @return	boolean
	 */
	public function delete() {
		//check ruleset for deleteable.
		if ($this->undeletable == 0) {
			// delete items
			$sql = "DELETE FROM	wcf".WCF_N."_rule_item
				WHERE		rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);
			
			// delete package links
			$sql = "DELETE FROM	wcf".WCF_N."_ruleset_to_package
				WHERE		rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);
			
			// delete user links
			$sql = "DELETE FROM	wcf".WCF_N."_ruleset_to_user
				WHERE		rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);
			
			// delete database entry
			$sql = "DELETE FROM	wcf".WCF_N."_ruleset
				WHERE		rulesetID = ".$this->rulesetID;
			WCF::getDB()->sendQuery($sql);
			return true;
		}
		else {
			return false;
		}
	}
	
	/**
	 * Creates a ruleset.
	 *
	 * @param	string		$name
	 */
	public static function create($name) {
		$sql = "INSERT INTO	wcf".WCF_N."_ruleset
					(name, undeletable, lastUpdate)
			VALUES		('".escapeString($name)."', 0, ".TIME_NOW.")";
		WCF::getDB()->sendQuery($sql);	
	}
	
	/**
	 * Build from all ruleset a option list.
	 *
	 * @return	array<string>
	 */
	public static function getOptionList() {
		$optionsList = array();
		
		// select all ruleset and make a option array for htmloptions
		$sql = "SELECT 		rulesetID, name
			FROM   		wcf".WCF_N."_ruleset
			ORDER BY 	rulesetID ASC";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$optionsList[$row['rulesetID']] = $row['name'];
		}
		
		return $optionsList;
	}
	
	/**
	 * Returns all rulesets.
	 *
	 * @return	array<Ruleset>
	 */
	public static function getRulesetList() {
		$rulesetList = array();
		$sql = "SELECT		*
			FROM		wcf".WCF_N."_ruleset
			ORDER BY	rulesetID ASC";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$rulesetList[] = new Ruleset(null, $row);
		}
		
		return $rulesetList;
	}
	
	/**
	 * Returns a list of all applications.
	 *
	 * @return	array<string>
	 */
	public static function getApplications() {
		$applicationList = array();
		
		// select all application packages with the ruleset ID. (WCF is not selected!)
		$sql = "SELECT		p.packageID, IF (p.instanceName <> '', p.instanceName, p.packageName) AS package, rtp.rulesetID
			FROM		wcf".WCF_N."_package p
			LEFT JOIN	wcf".WCF_N."_ruleset_to_package rtp
			ON 		(rtp.packageID = p.packageID)
			WHERE		p.standalone = 1
					AND p.packageID <> 1";
		$result = WCF::getDB()->sendQuery($sql);
		while ($row = WCF::getDB()->fetchArray($result)) {
			$applicationList[] = $row;
		}

		return $applicationList;
	}
	
	/**
	 * Check the name of a ruleset.
	 *
	 * @param	string		$name
	 * @param	int		$rulesetID
	 * @return	boolean
	 */
	public static function existName($name, $rulesetID = 0) {
		$sql = "SELECT	COUNT(*) AS count
			FROM	wcf".WCF_N."_ruleset
			WHERE	name = '".escapeString($name)."'
			".(($rulesetID != 0) ? (" AND rulesetID != ".$rulesetID) : (""));
		$row = WCF::getDB()->getFirstRow($sql);
		return ($row['count'] > 0) ? true : false;
	}
}
?>