<?php
//wcf imports
require_once(WCF_DIR.'lib/form/AbstractForm.class.php');
require_once(WCF_DIR.'lib/data/rule/Ruleset.class.php');
require_once(WCF_DIR.'lib/page/util/menu/PageMenu.class.php');

/**
 * Show the term of use agree form.
 *
 * @author 	Karsten Achterrath
 * @copyright	2001-2009 WoltLab GmbH
 * @license	WoltLab Burning Board License <http://www.woltlab.com/products/burning_board/license.php>
 * @package	com.woltlab.wcf.termsOfUse
 * @subpackage	form
 * @category 	Community Framework (commercial)
 */
class RulesAgreeForm extends AbstractForm { 
	public $templateName = 'rulesAgree';
	public $rulesAgree = 0;
	public $ruleList = null;
	public $ruleset = null;
	
	/**
	 * @see	Page::readParameters()
	 */
	public function readParameters() {
		parent::readParameters();
		
		$this->ruleset = Ruleset::getActiveRuleset(PACKAGE_ID);	
	}
	
	/**
	 * @see Form::readFormParameters()
	 */
	public function readFormParameters() {
		parent::readFormParameters();
		
		if (isset($_POST['rulesAgree'])) $this->rulesAgree = intval($_POST['rulesAgree']);
	}
	
	/**
	 * @see	Form::validate()
	 */
	public function validate() {
		parent::validate();
		
		if ($this->rulesAgree == 0) {
			throw new UserInputException('rulesAgree');
		}
	}
	
	/**
	 * @see Form::save()
	 */
	public function save() {
		parent::save();
		
		// make the user agreement
		$this->ruleset->makeUserAgree(WCF::getUser()->userID);

		// save package id to session variable
		$packages = WCF::getSession()->getVar('package_agrees');
		if (is_null($packages) || !is_array($packages)) $packages = array(PACKAGE_ID);
		else $packages[] = PACKAGE_ID;
		WCF::getSession()->register('package_agrees', $packages);
		
		parent::saved();
		HeaderUtil::redirect('index.php?page=Index'.SID_ARG_2ND_NOT_ENCODED);
	}
	
	/**
	 * @see Page::readData()
	 */
	public function readData() {
		parent::readData();
		
		$this->ruleList = $this->ruleset->getRuleList();
		PageMenu::setActiveMenuItem('wcf.header.menu.rules');
	}
	
	/**
	 * @see Page::assignVariables()
	 */
	public function assignVariables() {
		parent::assignVariables();
		
		WCF::getTPL()->assign('ruleList', $this->ruleList);
	}
}
?>